#ifndef GLMMROPTIM_H
#define GLMMROPTIM_H

#include <cmath> 
#include <RcppEigen.h>
#include "optim/optimmaths.h"
#include "optim/matrixfield.h"
#include "optim/optimclass.h"
#include "optim/optimdata.h"
#include <glmmr/openmpheader.h>

#endif
